@@ -1,26 +1,26 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ----data, fig.align='center', fig.height=5, fig.width=4.5---------------
+## ----data, fig.align='center', fig.height=5, fig.width=4.5--------------------
 library(bvartools)
 
 data("e6")
 
 plot(e6) # Plot the series
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data <- gen_vec(e6, p = 4, const = "unrestricted", season = "unrestricted")
 
 y <- data$Y
 w <- data$W
 x <- data$X
 
-## ----flat prior----------------------------------------------------------
+## ----flat prior---------------------------------------------------------------
 # Reset random number generator for reproducibility
-set.seed(1234567)
+set.seed(7654321)
 
 iter <- 10000 # Number of iterations of the Gibbs sampler
 burnin <- 5000 # Number of burn-in draws
@@ -28,7 +28,7 @@ store <- iter - burnin
 
 r <- 1 # Set rank
 
-t <- ncol(y) # Number of observations
+tt <- ncol(y) # Number of observations
 k <- nrow(y) # Number of endogenous variables
 k_w <- nrow(w) # Number of regressors in error correction term
 k_x <- nrow(x) # Number of differenced regressors and unrestrictec deterministic terms
@@ -42,19 +42,21 @@ a_mu_prior <- matrix(0, k_x * k) # Vector of prior parameter means
 a_v_i_prior <- diag(0, k_x * k) # Inverse of the prior covariance matrix
 
 v_i <- 0
-p_tau_i <- diag(1, k_w)
+p_tau_i <- matrix(0, k_w, k_w)
+p_tau_i[1:r, 1:r] <- diag(1, r)
 
-u_sigma_df_prior <- r # Prior degrees of freedom
-u_sigma_scale_prior <- diag(0, k) # Prior covariance matrix
-u_sigma_df_post <- t + u_sigma_df_prior # Posterior degrees of freedom
+sigma_df_prior <- k + r # Prior degrees of freedom
+sigma_scale_prior <- diag(0, k) # Prior covariance matrix
+sigma_df_post <- tt + sigma_df_prior # Posterior degrees of freedom
 
 # Initial values
-beta <- matrix(c(1, -4), k_w, r)
+beta <- matrix(0, k_w, r)
+beta[1:r, 1:r] <- diag(1, r)
 
-u_sigma_i <- diag(.0001, k)
-u_sigma <- solve(u_sigma_i)
+sigma_i <- diag(.00001, k)
+sigma <- solve(sigma_i)
 
-g_i <- u_sigma_i
+g_i <- sigma_i
 
 # Data containers
 draws_alpha <- matrix(NA, k_alpha, store)
@@ -66,10 +68,10 @@ draws_sigma <- matrix(NA, k^2, store)
 # Start Gibbs sampler
 for (draw in 1:iter) {
   # Draw conditional mean parameters
-  temp <- post_coint_kls(y = y, beta = beta, w = w, x = x, sigma_i = u_sigma_i,
+  temp <- post_coint_kls(y = y, beta = beta, w = w, x = x, sigma_i = sigma_i,
                            v_i = v_i, p_tau_i = p_tau_i, g_i = g_i,
                            gamma_mu_prior = a_mu_prior,
-                           gamma_V_i_prior = a_v_i_prior)
+                           gamma_v_i_prior = a_v_i_prior)
   alpha <- temp$alpha
   beta <- temp$beta
   Pi <- temp$Pi
@@ -77,12 +79,12 @@ for (draw in 1:iter) {
   
   # Draw variance-covariance matrix
   u <- y - Pi %*% w - matrix(gamma, k) %*% x
-  u_sigma_scale_post <- solve(tcrossprod(u) + v_i * alpha %*% tcrossprod(crossprod(beta, p_tau_i) %*% beta, alpha))
-  u_sigma_i <- matrix(rWishart(1, u_sigma_df_post, u_sigma_scale_post)[,, 1], k)
-  u_sigma <- solve(u_sigma_i)
+  sigma_scale_post <- solve(tcrossprod(u) + v_i * alpha %*% tcrossprod(crossprod(beta, p_tau_i) %*% beta, alpha))
+  sigma_i <- matrix(rWishart(1, sigma_df_post, sigma_scale_post)[,, 1], k)
+  sigma <- solve(sigma_i)
   
   # Update g_i
-  g_i <- u_sigma_i
+  g_i <- sigma_i
   
   # Store draws
   if (draw > burnin) {
@@ -90,35 +92,19 @@ for (draw in 1:iter) {
     draws_beta[, draw - burnin] <- beta
     draws_pi[, draw - burnin] <- Pi
     draws_gamma[, draw - burnin] <- gamma
-    draws_sigma[, draw - burnin] <- u_sigma
+    draws_sigma[, draw - burnin] <- sigma
   }
 }
 
-## ------------------------------------------------------------------------
-Gamma <- rowMeans(draws_gamma) # Obtain means for every row
-Gamma <- matrix(Gamma, k) # Transform mean vector into a matrix
-Gamma <- round(Gamma, 3) # Round values
-dimnames(Gamma) <- list(dimnames(y)[[1]], dimnames(x)[[1]]) # Rename matrix dimensions
-
-round(Gamma, 3) # Print
-
-## ----beta----------------------------------------------------------------
-beta <- rowMeans(t(t(draws_beta) / t(draws_beta)[, 1])) # Obtain means for every row
+## ----beta---------------------------------------------------------------------
+beta <- apply(t(draws_beta) / t(draws_beta)[, 1], 2, mean) # Obtain means for every row
 beta <- matrix(beta, k_w) # Transform mean vector into a matrix
 beta <- round(beta, 3) # Round values
 dimnames(beta) <- list(dimnames(w)[[1]], NULL) # Rename matrix dimensions
 
 beta # Print
 
-## ------------------------------------------------------------------------
-Sigma <- rowMeans(draws_sigma) # Obtain means for every row
-Sigma <- matrix(Sigma, k) # Transform mean vector into a matrix
-Sigma <- round(Sigma * 10^4, 2) # Round values
-dimnames(Sigma) <- list(dimnames(y)[[1]], dimnames(y)[[1]]) # Rename matrix dimensions
-
-Sigma # Print
-
-## ----bvec-object---------------------------------------------------------
+## ----bvec-object--------------------------------------------------------------
 # Number of non-deterministic coefficients
 k_nondet <- (k_x - 4) * k
 
@@ -129,33 +115,36 @@ bvec_est <- bvec(y = y, w = w, x = x,
                C = draws_gamma[(k_nondet + 1):nrow(draws_gamma),],
                Sigma = draws_sigma)
 
-## ----thin----------------------------------------------------------------
+## -----------------------------------------------------------------------------
+summary(bvec_est)
+
+## ----thin---------------------------------------------------------------------
 bvec_est <- thin(bvec_est, thin = 5)
 
-## ----vec2var-------------------------------------------------------------
+## ----vec2var------------------------------------------------------------------
 bvar_form <- bvec_to_bvar(bvec_est)
 
-## ----forecast, , fig.width=5.5, fig.height=5.5---------------------------
+## ----forecast, , fig.width=5.5, fig.height=5.5--------------------------------
 bvar_pred <- predict(bvar_form, n.ahead = 10, new_D = t(bvar_form$x[9:12, 91:100]))
 
 plot(bvar_pred)
 
-## ----feir, fig.width=5.5, fig.height=4.5---------------------------------
+## ----feir, fig.width=5.5, fig.height=4.5--------------------------------------
 IR <- irf(bvar_form, impulse = "R", response = "Dp", n.ahead = 20)
 
 plot(IR, main = "Forecast Error Impulse Response", xlab = "Year", ylab = "Response")
 
-## ----oir, fig.width=5.5, fig.height=4.5----------------------------------
+## ----oir, fig.width=5.5, fig.height=4.5---------------------------------------
 OIR <- irf(bvar_form, impulse = "R", response = "Dp", n.ahead = 20, type = "oir")
 
 plot(OIR, main = "Orthogonalised Impulse Response", xlab = "Year", ylab = "Response")
 
-## ----gir, fig.width=5.5, fig.height=4.5----------------------------------
+## ----gir, fig.width=5.5, fig.height=4.5---------------------------------------
 GIR <- irf(bvar_form, impulse = "R", response = "Dp", n.ahead = 20, type = "gir")
 
 plot(GIR, main = "Generalised Impulse Response", xlab = "Year", ylab = "Response")
 
-## ----fevd, fig.width=5.5, fig.height=4.5---------------------------------
+## ----fevd, fig.width=5.5, fig.height=4.5--------------------------------------
 bvec_fevd <- fevd(bvar_form, response = "Dp", n.ahead = 20)
 
 plot(bvec_fevd, main = "FEVD of inflation")
