@@ -12,6 +12,9 @@
 //' For time varying variance-covariance matrics a \eqn{KT \times K} can be provided.
 //' @param a_prior a \eqn{M x 1} numeric vector of prior means.
 //' @param v_i_prior the inverse of the \eqn{M x M} prior covariance matrix.
+//' @param svd logical. If \code{TRUE} the singular value decomposition is used to determine
+//' the root of the posterior covariance matrix. Default is \code{FALSE} which means
+//' that the eigenvalue decomposition is used.
 //' 
 //' @details The function produces a posterior draw of the coefficient vector \eqn{a} for the model
 //' \deqn{y_{t} = Z_{t} a + u_{t},}
@@ -52,14 +55,26 @@
 //' @return A vector.
 //' 
 // [[Rcpp::export]]
-arma::vec post_normal_sur(arma::mat y ,arma::mat z, arma::mat sigma_i,
-                          arma::vec a_prior, arma::mat v_i_prior) {
+arma::mat post_normal_sur(arma::mat y ,arma::mat z, arma::mat sigma_i,
+                          arma::vec a_prior, arma::mat v_i_prior, bool svd = false) {
+  
+  if (sigma_i.has_nan()) {
+    Rcpp::stop("Argument 'sigma_i' contains NAs.");
+  }
   
   arma::uword n = y.n_rows;
   int t = y.n_cols;
   int nvars = z.n_cols;
+  int n_mu = a_prior.n_rows;
+  int n_v = v_i_prior.n_rows;
+  if (nvars != n_mu) {
+    Rcpp::stop("Argument 'a_prior' does not contain the required amount of elements.");
+  }
+  if (nvars != n_v) {
+    Rcpp::stop("Argument 'v_i_prior' does not contain the required amount of elements.");
+  }
+  
   bool const_var = true;
-  arma::mat S_i = arma::zeros<arma::mat>(n * t, n * t);
   if (sigma_i.n_rows > n) {
     const_var = false;
   }
@@ -68,9 +83,11 @@ arma::vec post_normal_sur(arma::mat y ,arma::mat z, arma::mat sigma_i,
   arma::mat ZHZ = arma::zeros<arma::mat>(nvars, nvars);
   arma::mat ZHy = arma::zeros<arma::mat>(nvars, 1);
   
+  arma::mat S_i;
   if (const_var) {
     ZHi = arma::trans(z) * arma::kron(arma::eye<arma::mat>(t, t), sigma_i);
   } else {
+    S_i = arma::zeros<arma::mat>(n * t, n * t);
     for (int i = 0; i < t; i++){
       S_i.submat(i * n, i * n, (i + 1) * n - 1, (i + 1) * n - 1) = sigma_i.rows(i * n, (i + 1) * n - 1);
     }
@@ -79,12 +96,17 @@ arma::vec post_normal_sur(arma::mat y ,arma::mat z, arma::mat sigma_i,
   ZHZ = ZHi * z;
   ZHy = ZHi * arma::vectorise(y);
   
-  arma::mat V_post = arma::inv(v_i_prior + ZHZ);
-  arma::vec mu_post = V_post * (v_i_prior * a_prior + ZHy);
+  arma::mat V_post_i = arma::inv(v_i_prior + ZHZ);
+  arma::vec mu_post =  V_post_i * (v_i_prior * a_prior + ZHy);
 
   arma::vec s;
-  arma::mat U;
-  arma::eig_sym(s, U, V_post);
+  arma::mat U, V;
+  if (svd) {
+    arma::svd(U, s, V, V_post_i);
+  } else {
+    arma::eig_sym(s, U, V_post_i);
+    V = U;
+  }
   
-  return mu_post + U * arma::diagmat(sqrt(s)) * arma::trans(U) * arma::randn<arma::vec>(nvars);
+  return mu_post + U * arma::diagmat(sqrt(s)) * arma::trans(V) * arma::randn<arma::vec>(nvars);
 }
